@@ -22,10 +22,20 @@ from requests.exceptions import (
     ConnectionError as RequestsConnectionError,
     RequestException as RequestsRequestException
 )
-from tenable.errors import *
 from tenable.utils import url_validator
 from tenable import __version__, __author__
 
+from tenable.errors import (
+		UnexpectedValueError,
+		InvalidInputError,
+		PermissionError,
+		NotFoundError,
+		UnsupportedError,
+		FileDownloadError,
+		ServerError,
+        UnknownError,
+        RetryError
+)
 
 class APIResultsIterator(object):
     '''
@@ -446,6 +456,13 @@ class APISession(object):
             ])
         })
 
+    def _close_session(self):
+        '''
+        Requests session destroy and close
+        '''
+        if self._session:
+            self._session.close()
+
     def _resp_error_check(self, response, **kwargs): #stub
         '''
         A more general response error checker that can be overloaded if needed.
@@ -515,7 +532,7 @@ class APISession(object):
             # The following code will run when a request successfully returned.
             else:
                 # If there is a Request UUID then we will want to log the UUID
-                # just incase we may need it for tracking down what happened
+                # just in case we may need it for tracking down what happened
                 # within the Tenable.io platform.
                 if resp.headers.get('x-request-uuid'):
                     self._log.debug('Request-UUID {} for {}'.format(
@@ -551,7 +568,7 @@ class APISession(object):
 
                 else:
                     # If all else fails, raise an error stating that we don't
-                    # even know whats happening.
+                    # even know what's happening.
                     raise UnknownError(resp)
         raise RetryError(resp, retries)
 
