@@ -2,6 +2,7 @@
 .. autoclass:: TenableIO
 
 .. automodule:: tenable.io.access_groups
+.. automodule:: tenable.io.access_groups_v2
 .. automodule:: tenable.io.agent_config
 .. automodule:: tenable.io.agent_exclusions
 .. automodule:: tenable.io.agent_groups
@@ -23,6 +24,7 @@
 .. automodule:: tenable.io.scanner_groups
 .. automodule:: tenable.io.scanners
 .. automodule:: tenable.io.scans
+.. automodule:: tenable.io.remediation_scans
 .. automodule:: tenable.io.server
 .. automodule:: tenable.io.session
 .. automodule:: tenable.io.tags
@@ -39,7 +41,7 @@ The methods listed below aren't run through any naturalization by the library
 aside from the response code checking.  These methods effectively route
 directly into the requests session.  The responses will be Response objects from
 the ``requests`` library.  In all cases, the path is appended to the base
-``url`` paramater that the ``TenableIO`` object was instantiated with.
+``url`` parameter that the ``TenableIO`` object was instantiated with.
 
 Example:
 
@@ -56,10 +58,11 @@ Example:
     .. automethod:: put
     .. automethod:: delete
 '''
-import logging, os
+import logging, os, warnings
 from tenable.errors import UnexpectedValueError
 from tenable.base.v1 import APISession
 from .access_groups import AccessGroupsAPI
+from .access_groups_v2 import AccessGroupsV2API
 from .agent_config import AgentConfigAPI
 from .agent_exclusions import AgentExclusionsAPI
 from .agent_groups import AgentGroupsAPI
@@ -81,6 +84,7 @@ from .policies import PoliciesAPI
 from .scanner_groups import ScannerGroupsAPI
 from .scanners import ScannersAPI
 from .scans import ScansAPI
+from .remediation_scans import RemediationScansAPI
 from .server import ServerAPI
 from .session import SessionAPI
 from .tags import TagsAPI
@@ -153,6 +157,10 @@ class TenableIO(APISession):
     def access_groups(self):
         return AccessGroupsAPI(self)
 
+    @property
+    def access_groups_v2(self):
+        return AccessGroupsV2API(self)
+
     @property
     def agent_config(self):
         return AgentConfigAPI(self)
@@ -221,6 +229,10 @@ class TenableIO(APISession):
     def plugins(self):
         return PluginsAPI(self)
 
+    @property
+    def pluginsIterator(self):
+        return plugins.PluginIterator(self)
+
     @property
     def policies(self):
         return PoliciesAPI(self)
@@ -237,12 +249,21 @@ class TenableIO(APISession):
     def scans(self):
         return ScansAPI(self)
 
+    @property
+    def remediationscans(self):
+        return RemediationScansAPI(self)
+
     @property
     def server(self):
         return ServerAPI(self)
 
     @property
     def session(self):
+        warnings.warn(
+            'Tenable.io session API is deprecated. '
+            'we recommends that you use users endpoint instead',
+            DeprecationWarning, 2
+        )
         return SessionAPI(self)
 
     @property
