@@ -67,7 +67,7 @@ Example:
     .. automethod:: delete
 '''
 from tenable.base.v1 import APISession
-from tenable.errors import *
+from tenable.errors import APIError, InvalidInputError, NotFoundError, ServerError, ConnectionError
 from .accept_risks import AcceptRiskAPI
 from .alerts import AlertAPI
 from .analysis import AnalysisAPI
@@ -184,7 +184,7 @@ class TenableSC(APISession):
         https://github.com/m-click/requests_pkcs12
     '''
     _apikeys = False
-    _restricted_paths = ['token']
+    _restricted_paths = ['token','credential']
     _timeout = 300
     _error_codes = {
         400: InvalidInputError,
@@ -208,7 +208,7 @@ class TenableSC(APISession):
         # reusable if the user logs out and logs back in.
         self._ssl_verify = ssl_verify
 
-        # Now lets pass the relevent parts off to the APISession's constructor
+        # Now lets pass the relevant parts off to the APISession's constructor
         # to make sure we have everything lined up as we expect.
         super(TenableSC, self).__init__(url,
             retries=retries,
@@ -318,9 +318,12 @@ class TenableSC(APISession):
             self._session.headers.update({
                 'X-SecurityCenter': str(resp.json()['response']['token'])
             })
+            self._session.headers.update({
+                'TNS_SESSIONID': str(resp.headers['Set-Cookie'])[14:46]
+            })
 
         elif access_key != None and secret_key != None:
-            if semver.match(self.version, '<5.13.0'):
+            if semver.VersionInfo.parse(self.version).match('<5.13.0'):
                 raise ConnectionError(
                     'API Keys not supported on this version of Tenable.sc')
             self._session.headers.update({
@@ -341,7 +344,7 @@ class TenableSC(APISession):
         '''
         if not self._apikeys:
             resp = self.delete('token')
-        self._build_session()
+        self._close_session()
         self._apikeys = False
 
     @property
