@@ -161,7 +161,7 @@ class AssetListAPI(SCEndpoint):
             del(kw['data_fields'])
 
         if 'combinations' in kw:
-            # if the combinations paramater is a tuple, then send the value to
+            # if the combinations parameter is a tuple, then send the value to
             # the combo_expansion method to convert the tuple to the dictionary
             # equivalent.  If the value is a dictionary, then simply pass the
             # value as-is.
@@ -346,7 +346,7 @@ class AssetListAPI(SCEndpoint):
                 an LDAP query.  must also provide a ``dn`` and a
                 ``search_string``.
             prep (bool, optional):
-                Should asset preperation be run after the list is created?  If
+                Should asset preparation be run after the list is created?  If
                 unspecified, the default action is ``True``.
             rules (tuple, optional):
                 For a dynamic asset list, the tuple definition of the rules to
@@ -440,29 +440,29 @@ class AssetListAPI(SCEndpoint):
         payload = self._constructor(**kw)
         return self._api.post('asset', json=payload).json()['response']
 
-    def details(self, id, fields=None):
+    def details(self, id, orgID, fields=None):
         '''
         Returns the details for a specific asset-list.
 
-        :sc-api:`asset-list: details <Asset.html#AssetRESTReference-/asset/{id}>`
+        :sc-api:`asset-list: details<Asset.html#AssetRESTReference-/asset/{id}?orgID={orgID}>`
 
         Args:
             id (int): The identifier for the asset-list.
+            orgID (int): The organizationID for the asset-list.
             fields (list, optional): A list of attributes to return.
 
         Returns:
-            dict: The asset-list resource record.
+            dict: The details of asset id.
 
         Examples:
-            >>> asset-list = sc.asset_lists.details(1)
-            >>> pprint(asset-list)
+            >>> asset_id_details = sc.asset_lists.details(1,1)
+            >>> pprint(asset_id_details)
         '''
         params = dict()
         if fields:
             params['fields'] = ','.join([self._check('field', f, str) for f in fields])
-
-        return self._api.get('asset/{}'.format(self._check('id', id, int)),
-            params=params).json()['response']
+        params['orgID']   = orgID
+        return self._api.get('asset/{}'.format(self._check('id', id,int)),params=params).json()['response']
 
     def edit(self, id, **kw):
         '''
@@ -511,7 +511,7 @@ class AssetListAPI(SCEndpoint):
             name (str, optional):
                 The name for the asset list to create.
             prep (bool, optional):
-                Should asset preperation be run after the list is created?  If
+                Should asset preparation be run after the list is created?  If
                 unspecified, the default action is ``True``.
             rules (tuple, optional):
                 For a dynamic asset list, the tuple definition of the rules to
@@ -676,7 +676,7 @@ class AssetListAPI(SCEndpoint):
         :sc-api:`asset-list: refresh <Asset.html#AssetRESTReference-/asset/{id}/refresh>`
 
         Args:
-            id (int): The numeric identifier fo the asset list to refresh.
+            id (int): The numeric identifier of the asset list to refresh.
             org_id (int): The organization associated to the asset list.
             *repos (int): Repository ids to perform the recalculation on.
 
